Crate locate_error_derive
locate_
error_
derive
0.1.1
All Items
Crate Items
Derive Macros
Crate
locate_
error_
derive
Derive Macros

Locate
This macro is used to implement
From
on an enum or struct and locating where the
From
impl is called. Typically used for tracking sources of bubbling errors with
thiserror
.